# vim: set sw=4 ts=4 et nu:
#
# spec file for package chromaprint
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           chromaprint
Version:        1.1
Release:        14.2
%define soname      0
Summary:        Audio Fingerprinting Library
License:        GPL-2.0+
Group:          System/Libraries
Source:         https://bitbucket.org/acoustid/chromaprint/downloads/chromaprint-%{version}.tar.gz
Source1:        baselibs.conf
Url:            http://acoustid.org/chromaprint
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fftw3-devel
BuildRequires:  libtag-devel
%if 0%{?_with_ffmpeg}
BuildRequires:  boost-devel
BuildRequires:  libffmpeg-devel
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  pkgconfig

%description
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%package -n libchromaprint%{soname}
Summary:        Audio Fingerprinting Library
License:        LGPL-2.1+
Group:          System/Libraries
%if 0%{?_with_ffmpeg}
Provides:       libchromaprint-with-ffmpeg = %{version}
%endif

%description -n libchromaprint%{soname}
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%package -n libchromaprint-devel
Summary:        Audio Fingerprinting Library
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       fftw3-devel
Requires:       libchromaprint%{soname} = %{version}
Requires:       libtag-devel
%if 0%{?_with_ffmpeg}
Requires:       libffmpeg-devel
Provides:       libchromaprint-devel-with-ffmpeg = %{version}
%endif

%description -n libchromaprint-devel
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.

%if 0%{?_with_ffmpeg}
%package fpcalc
Summary:        Chromaprint Audio Fingerprinting Command Line Tool
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       libchromaprint%{soname} = %{version}
Provides:       fpcalc = %{version}

%description fpcalc
Chromaprint is the core component of the Acoustid project. It's a client-side
library that implements a custom algorithm for extracting fingerprints from any
audio source.
This package contains fpcalc, a command-line tool to perform Chromaprint
fingerprinting.
%endif

%prep
%setup -q

%build
%__install -d build
pushd build
cmake \
    -DCMAKE_VERBOSE_MAKEFILE=TRUE \
    -DCMAKE_INSTALL_PREFIX="%{_prefix}" \
    -DCMAKE_SKIP_RPATH=TRUE \
    -DCMAKE_BUILD_WITH_INSTALL_RPATH=FALSE \
%if 0%{?suse_version}
%if "%{_lib}" == "lib64"
    -DLIB_SUFFIX="64" \
%endif
%endif
%if 0%{?_with_ffmpeg}
    -DWITH_AVFFT=ON \
    -DBUILD_EXAMPLES=ON \
%endif
    ..
%__make %{?_smp_mflags}
popd

%install
pushd build
%makeinstall
popd

%post   -n libchromaprint%{soname} -p /sbin/ldconfig

%postun -n libchromaprint%{soname} -p /sbin/ldconfig

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files -n libchromaprint%{soname}
%defattr(-,root,root)
%doc COPYING.txt NEWS.txt README.txt
%{_libdir}/libchromaprint.so.%{soname}
%{_libdir}/libchromaprint.so.%{soname}.*

%files -n libchromaprint-devel
%defattr(-,root,root)
%{_includedir}/chromaprint.h
%{_libdir}/libchromaprint.so
%{_libdir}/pkgconfig/libchromaprint.pc

%if 0%{?_with_ffmpeg}
%files fpcalc
%defattr(-,root,root)
%{_bindir}/fpcalc
%endif

%changelog
* Wed Dec 10 2014 olaf@aepfle.de
- Update to version 1.1
  - Fixed potential DoS attack in fingerprint decompression code. (#6)
  - Fixed invalid memory read with some fingerprinter configurations. (#5)
  - Added support for audio format conversion with libav. (#2, Gordon Pettey)
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
* Wed Oct 30 2013 joerg.lorenzen@ki.tng.de
- Update to version 1.0
  - Support for the latest FFmpeg API.
  - Support for reading audio from stdin in fpcalc.
  - Changed fpcalc to return non-zero status on failure.
* Tue Mar 19 2013 schwab@suse.de
- Properly determine LIB_SUFFIX
* Fri Nov  9 2012 hrvoje.senjan@gmail.com
- Update to version 0.7
  - Support for the latest FFmpeg API.
  - New (non-default) fingerprint algorithm that removes leading silence.
  - API to configure fingerprint algorithms, currently only used by
  CHROMAPRINT_ALGORITHM_TEST4.
* Tue May 29 2012 Manfred.Tremmel@iiv.de
- ffmpeg doen't include url.h anymorecompile against ffmpeg_oldabi
* Sat May 19 2012 pascal.bleser@opensuse.org
- initial version (0.6)
